@@ -195,7 +195,6 @@ rabbit_opts = [
                'Used only when rabbit_quorum_queue is enabled, '
                'Default 0 which means dont set a limit.'),
     cfg.IntOpt('rabbit_quorum_max_memory_length',
-               deprecated_name='rabbit_quroum_max_memory_length',
                default=0,
                help='By default all messages are maintained in memory '
                'if a quorum queue grows in length it can put memory '
@@ -204,7 +203,6 @@ rabbit_opts = [
                'Used only when rabbit_quorum_queue is enabled, '
                'Default 0 which means dont set a limit.'),
     cfg.IntOpt('rabbit_quorum_max_memory_bytes',
-               deprecated_name='rabbit_quroum_max_memory_bytes',
                default=0,
                help='By default all messages are maintained in memory '
                'if a quorum queue grows in length it can put memory '
@@ -457,8 +455,8 @@ class Consumer:
     def reset_stream_offset(self):
         if not self.rabbit_stream_fanout:
             return
-        LOG.warn("Reset consumer for queue %s next offset was at %s.",
-                 self.queue_name, self.next_stream_offset)
+        LOG.warning("Reset consumer for queue %s next offset was at %s.",
+                    self.queue_name, self.next_stream_offset)
         self.next_stream_offset = "last"
 
     def declare(self, conn):
@@ -1114,9 +1112,9 @@ class Connection:
                 # happen, for example, when we delete the stream queue.
                 # We need to start consuming from "last" because the stream
                 # offset maybe reset.
-                LOG.warn('[%s] Basic.cancel received. '
-                         'Resetting consumers offsets to last.',
-                         self.connection_id)
+                LOG.warning('[%s] Basic.cancel received. '
+                            'Resetting consumers offsets to last.',
+                            self.connection_id)
                 for consumer in self._consumers:
                     consumer.reset_stream_offset()
 
@@ -1796,6 +1794,13 @@ class RabbitDriver(amqpdriver.AMQPDriverBase):
             conf, max_size, min_size, ttl,
             url, Connection)
 
+        if conf.oslo_messaging_rabbit.use_queue_manager:
+            self._q_manager = amqpdriver.QManager(
+                hostname=conf.oslo_messaging_rabbit.hostname,
+                processname=conf.oslo_messaging_rabbit.processname)
+        else:
+            self._q_manager = None
+
         super().__init__(
             conf, url,
             connection_pool,
@@ -1803,5 +1808,11 @@ class RabbitDriver(amqpdriver.AMQPDriverBase):
             allowed_remote_exmods
         )
 
+    def _get_reply_queue_name(self):
+        if self._q_manager:
+            return 'reply_' + self._q_manager.get()
+        else:
+            return super()._get_reply_queue_name()
+
     def require_features(self, requeue=True):
         pass
